summaryrefslogtreecommitdiffstats
path: root/konversation/src/konvibookmarkmenu.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'konversation/src/konvibookmarkmenu.cpp')
-rw-r--r--konversation/src/konvibookmarkmenu.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/konversation/src/konvibookmarkmenu.cpp b/konversation/src/konvibookmarkmenu.cpp
index d4685e0..5d0bb4b 100644
--- a/konversation/src/konvibookmarkmenu.cpp
+++ b/konversation/src/konvibookmarkmenu.cpp
@@ -34,12 +34,12 @@ m_kOwner(_owner)
/*
* First, we disconnect KBookmarkMenu::slotAboutToShow()
* Then, we connect KonviBookmarkMenu::slotAboutToShow().
* They are named differently because the TQT_SLOT() macro thinks we want
* KonviBookmarkMenu::KBookmarkMenu::slotAboutToShow()
* Could this be solved if slotAboutToShow() is virtual in KBookmarMenu?
*/
- disconnect(_parentMenu, TQT_SIGNAL(aboutToShow()), this, TQT_SLOT(slotAboutToShow()));
- connect(_parentMenu, TQT_SIGNAL(aboutToShow()), TQT_SLOT(slotAboutToShow2()));
+ disconnect(_parentMenu, TQ_SIGNAL(aboutToShow()), this, TQ_SLOT(slotAboutToShow()));
+ connect(_parentMenu, TQ_SIGNAL(aboutToShow()), TQ_SLOT(slotAboutToShow2()));
}
/*
@@ -110,7 +110,7 @@ void KonviBookmarkMenu::fillBookmarkMenu()
// kdDebug(1203) << "Creating URL bookmark menu item for " << bm.text() << endl;
// create a normal URL item, with ID as a name
TDEAction * action = new TDEAction( text, bm.icon(), 0,
- this, TQT_SLOT( slotBookmarkSelected() ),
+ this, TQ_SLOT( slotBookmarkSelected() ),
m_actionCollection, bm.url().url().utf8() );
action->setStatusText( bm.url().prettyURL() );
@@ -34,12 +34,12 @@ m_kOwner(_owner)
* First, we disconnect KBookmarkMenu::slotAboutToShow()
* Then, we connect KonviBookmarkMenu::slotAboutToShow().
- * They are named differently because the TQT_SLOT() macro thinks we want
+ * They are named differently because the TQ_SLOT() macro thinks we want
* KonviBookmarkMenu::KBookmarkMenu::slotAboutToShow()
* Could this be solved if slotAboutToShow() is virtual in KBookmarMenu?